##  Applications in Scope
The reference catalog provides the following data:
  * SAP applications
  * SAP AI agents
  * SaaS applications


A SaaS (Software as a Service) application is a software delivered on-demand and ready to use over the internet. It serves customers without having to install the software on individual systems or on-premise servers. Authorized users can access SaaS applications from anywhere on any authorized device.
The following attributes help to identify if an application is SaaS or not. A SaaS application:
  * Is available online and ready to use
  * Is licensed based on a subscription, for free, or pay-as-you-go model
  * Requires a login to get access
  * Is accessible from different devices (for example, desktop computers and mobile devices)
  * Is hosted centrally in the cloud
  * Doesn't require a dedicated infrastructure from the client
